@@ -21,9 +21,31 @@
 !
 program f90_unix_file_tst
   use f90_unix_file
+  use f90_unix_proc, only : system
   implicit none
 
+  type(stat_t) :: buf
+  integer :: errno
 
+  call access("f90_unix_file_tst", X_OK, errno)
+  call check_errno(errno, 'access("f90_unix_file_tst", X_OK, errno)')
+
+  call system("touch tstfile")
+  call chmod("tstfile", S_IXUSR, errno)
+  call check_errno(errno, 'chmod("tstfile", S_IXUSR, errno)')
+
+  call chown("tstfile", 100, 100, errno)
+  call check_errno(errno, 'chown("tstfile", 100, 100, errno)',1)
+
+  call stat("tstfile", buf, errno)
+  call check_errno(errno, 'stat(tstfile, buf, errno)')
+  print 1000, buf%st_dev, buf%st_ino, buf%st_mode, buf%st_nlink,&
+         & buf%st_uid, buf%st_gid, buf%st_rdev, buf%st_size, buf%st_atime,&
+         & buf%st_mtime, buf%st_ctime
+1000 format("dev=", I4, " ino=", I8, " mode=", I6, " nlink=", I2, " uid=", I4,&
+          &" gid=", I4, " rdev=" ,I8, " size=", I2, " atime", I10,&
+          &" mtime", I10, " ctime", I10)
+  call system("rm -f tstfile")
 contains
 
   subroutine check_errno(errno, msg, flag)
